package com.ruoyi.ems.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.utils.uuid.Seq;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AdmOpInspectionTask;
import com.ruoyi.ems.service.IAdmOpInspectionTaskService;

/**
 * 巡检任务Controller
 *
 * @author ruoyi
 * @date 2024-08-29
 */
@RestController
@RequestMapping("/inspectionTask")
public class AdmOpInspectionTaskController extends BaseController {
    @Autowired
    private IAdmOpInspectionTaskService admOpInspectionTaskService;

    /**
     * 查询巡检任务列表
     */
    @RequiresPermissions("ems:inspection-task:list")
    @GetMapping("/list")
    public TableDataInfo list(AdmOpInspectionTask admOpInspectionTask) {
        startPage();
        List<AdmOpInspectionTask> list = admOpInspectionTaskService.selectAdmOpInspectionTaskList(admOpInspectionTask);
        return getDataTable(list);
    }

    /**
     * 导出巡检任务列表
     */
    @RequiresPermissions("ems:inspection-task:export")
    @Log(title = "巡检任务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmOpInspectionTask admOpInspectionTask) {
        List<AdmOpInspectionTask> list = admOpInspectionTaskService.selectAdmOpInspectionTaskList(admOpInspectionTask);
        ExcelUtil<AdmOpInspectionTask> util = new ExcelUtil<AdmOpInspectionTask>(AdmOpInspectionTask.class);
        util.exportExcel(response, list, "巡检任务数据");
    }

    /**
     * 获取巡检任务详细信息
     */
    @RequiresPermissions("ems:inspection-task:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(admOpInspectionTaskService.selectAdmOpInspectionTaskById(id));
    }

    /**
     * 新增巡检任务
     */
    @RequiresPermissions("ems:inspection-task:add")
    @Log(title = "巡检任务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmOpInspectionTask admOpInspectionTask) {
        admOpInspectionTask.setTaskCode(Seq.getId());
        return toAjax(admOpInspectionTaskService.insertAdmOpInspectionTask(admOpInspectionTask));
    }

    /**
     * 修改巡检任务
     */
    @RequiresPermissions("ems:inspection-task:edit")
    @Log(title = "巡检任务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmOpInspectionTask admOpInspectionTask) {
        return toAjax(admOpInspectionTaskService.updateAdmOpInspectionTask(admOpInspectionTask));
    }

    /**
     * 删除巡检任务
     */
    @RequiresPermissions("ems:inspection-task:remove")
    @Log(title = "巡检任务", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(admOpInspectionTaskService.deleteAdmOpInspectionTaskByIds(ids));
    }
}
